summaryrefslogtreecommitdiff
path: root/xmloff/inc/XMLThemeContext.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'xmloff/inc/XMLThemeContext.hxx')
-rw-r--r--xmloff/inc/XMLThemeContext.hxx12
1 files changed, 6 insertions, 6 deletions
diff --git a/xmloff/inc/XMLThemeContext.hxx b/xmloff/inc/XMLThemeContext.hxx
index a270d58bec99..ce6f5ec9bbb6 100644
--- a/xmloff/inc/XMLThemeContext.hxx
+++ b/xmloff/inc/XMLThemeContext.hxx
@@ -38,18 +38,18 @@ public:
const css::uno::Reference<css::xml::sax::XFastAttributeList>& xAttribs) override;
};
-/// Imports the color table of a theme
-class XMLColorTableContext : public SvXMLImportContext
+/// Imports the theme colors of a theme
+class XMLThemeColorsContext : public SvXMLImportContext
{
model::Theme& mrTheme;
std::shared_ptr<model::ColorSet> m_pColorSet;
std::vector<css::util::Color> m_aColorScheme;
public:
- XMLColorTableContext(SvXMLImport& rImport,
- css::uno::Reference<css::xml::sax::XFastAttributeList> const& xAttrList,
- model::Theme& mrTheme);
- ~XMLColorTableContext();
+ XMLThemeColorsContext(SvXMLImport& rImport,
+ css::uno::Reference<css::xml::sax::XFastAttributeList> const& xAttrList,
+ model::Theme& mrTheme);
+ ~XMLThemeColorsContext();
css::uno::Reference<css::xml::sax::XFastContextHandler> SAL_CALL createFastChildContext(
sal_Int32 nElement,